@@ -37,6 +37,7 @@ namespaces = {
     'ogc': 'http://www.opengis.net/ogc',
     'ows': 'http://www.opengis.net/ows',
     'rim': 'urn:oasis:names:tc:ebxml-regrep:xsd:rim:3.0',
+    'rdf': 'http://www.w3.org/1999/02/22-rdf-syntax-ns#',
     'xs' : 'http://www.w3.org/2001/XMLSchema',
     'xs2': 'http://www.w3.org/XML/Schema',
     'xsi': 'http://www.w3.org/2001/XMLSchema-instance'
@@ -505,6 +506,15 @@ class CswRecord(object):
         else:  # part of a larger document
             self.xml = etree.tostring(record)
 
+        # check to see if Dublin Core record comes from
+        # rdf:RDF/rdf:Description container
+        # (child content model is identical)
+        self.rdf = False
+        rdf = record.find(util.nspath_eval('rdf:Description', namespaces))
+        if rdf is not None:
+            self.rdf = True
+            record = rdf
+
         # some CSWs return records with multiple identifiers based on 
         # different schemes.  Use the first dc:identifier value to set
         # self.identifier, and set self.identifiers as a list of dicts
